@@ -5,9 +5,10 @@ class Registry(BaseCheckRegistry):
 
     def extract_entity_details(self, entity):
         resource_name, resource = next(iter(entity.items()))
-        resource_type = str(resource['type'])    # entity['type'] ??
+        resource_type = str(resource.get('type', ''))    # entity['type'] ??
         return resource_type, resource_name, resource
 
+
 '''
     def scan(self, scanned_file, entity, skipped_checks, runner_filter=None):
         entity_type, entity_configuration = self.extract_entity_details(entity)
