@@ -1,45 +1,42 @@
+import re
+from typing import Union, Dict, Any
+
 from checkov.common.models.enums import CheckResult, CheckCategories
 from checkov.arm.base_resource_check import BaseResourceCheck
-#from checkov.arm.base_resource_value_check import BaseResourceCheck
-import re
-
-'''
-from checkov.common.models.enums import CheckResult, CheckCategories
-from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceCheck
-from checkov.common.util.type_forcers import force_list
-import re
-'''
 
 # https://docs.microsoft.com/en-us/azure/templates/microsoft.network/networksecuritygroups
 # https://docs.microsoft.com/en-us/azure/templates/microsoft.network/networksecuritygroups/securityrules
 
-INTERNET_ADDRESSES = ["*", "0.0.0.0", "<nw>/0", "/0", "internet", "any"] # nosec
+INTERNET_ADDRESSES = ["*", "0.0.0.0", "<nw>/0", "/0", "internet", "any"]  # nosec
 PORT_RANGE = re.compile(r"\d+-\d+")
 
+
 class NSGRulePortAccessRestricted(BaseResourceCheck):
-    def __init__(self, name, check_id, port):
-        supported_resources = ['Microsoft.Network/networkSecurityGroups',
-                               'Microsoft.Network/networkSecurityGroups/securityRules']
-        categories = [CheckCategories.NETWORKING]
+    def __init__(self, name: str, check_id: str, port: int) -> None:
+        supported_resources = (
+            "Microsoft.Network/networkSecurityGroups",
+            "Microsoft.Network/networkSecurityGroups/securityRules",
+        )
+        categories = (CheckCategories.NETWORKING,)
         super().__init__(name=name, id=check_id, categories=categories, supported_resources=supported_resources)
         self.port = port
 
-    def is_port_in_range(self, portRange):
-        if re.match(PORT_RANGE, str(portRange)):
-            start, end = int(portRange.split('-')[0]), int(portRange.split('-')[1])
+    def is_port_in_range(self, port_range: Union[int, str]) -> bool:
+        if re.match(PORT_RANGE, str(port_range)):
+            start, end = int(port_range.split("-")[0]), int(port_range.split("-")[1])
             if start <= self.port <= end:
                 return True
-        if portRange in [str(self.port), '*']:
+        if port_range in (str(self.port), "*"):
             return True
         return False
 
-    def scan_resource_conf(self, conf):
+    def scan_resource_conf(self, conf: Dict[str, Any]) -> CheckResult:
         if "properties" in conf:
             securityRules = []
-            if "type" in conf and conf["type"] == "Microsoft.Network/networkSecurityGroups":
+            if self.entity_type == "Microsoft.Network/networkSecurityGroups":
                 if "securityRules" in conf["properties"]:
                     securityRules.extend(conf["properties"]["securityRules"])
-            if "type" in conf and conf["type"] == "Microsoft.Network/networkSecurityGroups/securityRules":
+            if self.entity_type == "Microsoft.Network/networkSecurityGroups/securityRules":
                 securityRules.append(conf)
 
             for rule in securityRules:
@@ -66,4 +63,3 @@ class NSGRulePortAccessRestricted(BaseResourceCheck):
                                                 return CheckResult.FAILED
 
         return CheckResult.PASSED
-
