@@ -3,6 +3,7 @@ Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
 """
 import logging
+import platform
 from enum import Enum
 from pathlib import Path
 from typing import List, Tuple
@@ -97,8 +98,17 @@ class NodeConstructor(SafeConstructor):
         for key_node, value_node in node.value:
             key = self.construct_object(key_node, False)
             value = self.construct_object(value_node, False)
-            if isinstance(key, dict):
-                key = frozenset(key.keys()), frozenset(key.values())
+            try:
+                if isinstance(key, dict):
+                    key = frozenset(key.keys()), frozenset(key.values())
+                if isinstance(key, list):
+                    key = frozenset(key)
+            except TypeError:
+                raise CfnParseError(
+                    self.filename,
+                    'Unable to construct key {} (line {})'.format(
+                        key, key_node.start_mark.line + 1),
+                    key_node.start_mark.line, key_node.start_mark.column, key)
             if key in mapping:
                 raise CfnParseError(
                     self.filename,
@@ -165,9 +175,14 @@ def multi_constructor(loader, tag_suffix, node):
     if tag_suffix not in UNCONVERTED_SUFFIXES:
         tag_suffix = '{}{}'.format(FN_PREFIX, tag_suffix)
 
-    constructor = None
     if tag_suffix == 'Fn::GetAtt':
         constructor = construct_getatt
+    elif tag_suffix == "Ref" and (isinstance(node.value, list) or isinstance(node.value, dict)):
+        raise CfnParseError(
+            filename="",
+            message='Invalid !Ref: {}'.format(node.value),
+            line_number=0,
+            column_number=0)
     elif isinstance(node, ScalarNode):
         constructor = loader.construct_scalar
     elif isinstance(node, SequenceNode):
@@ -212,13 +227,19 @@ def load(filename: Path, content_type: ContentType) -> Tuple[DictNode, List[Tupl
     """
     Load the given YAML file
     """
-
-    file_path = filename if isinstance(filename, Path) else Path(filename)
-    try:
-        content = file_path.read_text()
-    except UnicodeDecodeError:
-        LOGGER.info(f"Encoding for file {filename} is not UTF-8, trying to detect it")
-        content = str(from_path(filename).best())
+    if platform.system() == "Windows":
+        try:
+            content = str(from_path(filename).best())
+        except UnicodeDecodeError as e:
+            LOGGER.error(f"Encoding for file {filename} could not be detected or read. Please try encoding the file as UTF-8.")
+            raise e
+    else:
+        file_path = filename if isinstance(filename, Path) else Path(filename)
+        try:
+            content = file_path.read_text()
+        except UnicodeDecodeError:
+            LOGGER.info(f"Encoding for file {filename} is not UTF-8, trying to detect it")
+            content = str(from_path(filename).best())
 
     if content_type == ContentType.CFN and "Resources" not in content:
         return {}, []
