@@ -10,20 +10,22 @@ from checkov.cloudformation.cfn_utils import create_definitions, build_definitio
 from checkov.cloudformation.checks.resource.registry import cfn_registry
 from checkov.cloudformation.context_parser import ContextParser
 from checkov.cloudformation.graph_builder.graph_components.block_types import BlockType
-from checkov.cloudformation.parser.cfn_keywords import TemplateSections
 from checkov.cloudformation.graph_builder.graph_to_definitions import convert_graph_vertices_to_definitions
 from checkov.cloudformation.graph_builder.local_graph import CloudformationLocalGraph
 from checkov.cloudformation.graph_manager import CloudformationGraphManager
+from checkov.cloudformation.parser.cfn_keywords import TemplateSections
 from checkov.common.checks_infra.registry import get_graph_checks_registry
 from checkov.common.graph.checks_infra.registry import BaseRegistry
 from checkov.common.graph.db_connectors.networkx.networkx_db_connector import NetworkxConnector
 from checkov.common.graph.graph_builder import CustomAttributes
 from checkov.common.graph.graph_builder.local_graph import LocalGraph
 from checkov.common.graph.graph_manager import GraphManager
+from checkov.common.output.extra_resource import ExtraResource
 from checkov.common.output.graph_record import GraphRecord
 from checkov.common.output.record import Record
 from checkov.common.output.report import Report, merge_reports, CheckType
 from checkov.common.runners.base_runner import BaseRunner, CHECKOV_CREATE_GRAPH
+from checkov.common.util.secrets import omit_secret_value_from_checks
 from checkov.runner_filter import RunnerFilter
 
 
@@ -31,12 +33,12 @@ class Runner(BaseRunner):
     check_type = CheckType.CLOUDFORMATION
 
     def __init__(
-        self,
-        db_connector: NetworkxConnector = NetworkxConnector(),
-        source: str = "CloudFormation",
-        graph_class: Type[LocalGraph] = CloudformationLocalGraph,
-        graph_manager: Optional[GraphManager] = None,
-        external_registries: Optional[List[BaseRegistry]] = None
+            self,
+            db_connector: NetworkxConnector = NetworkxConnector(),
+            source: str = "CloudFormation",
+            graph_class: Type[LocalGraph] = CloudformationLocalGraph,
+            graph_manager: Optional[GraphManager] = None,
+            external_registries: Optional[List[BaseRegistry]] = None
     ) -> None:
         super().__init__(file_extensions=['.json', '.yml', '.yaml', '.template'])
         self.external_registries = [] if external_registries is None else external_registries
@@ -50,18 +52,22 @@ class Runner(BaseRunner):
         self.graph_registry = get_graph_checks_registry(self.check_type)
 
     def run(
-        self,
-        root_folder: str,
-        external_checks_dir: Optional[List[str]] = None,
-        files: Optional[List[str]] = None,
-        runner_filter: RunnerFilter = RunnerFilter(),
-        collect_skip_comments: bool = True,
+            self,
+            root_folder: str,
+            external_checks_dir: Optional[List[str]] = None,
+            files: Optional[List[str]] = None,
+            runner_filter: RunnerFilter = RunnerFilter(),
+            collect_skip_comments: bool = True,
     ) -> Report:
+        if not runner_filter.show_progress_bar:
+            self.pbar.turn_off_progress_bar()
+
         report = Report(self.check_type)
         parsing_errors: dict[str, str] = {}
 
         if self.context is None or self.definitions is None or self.breadcrumbs is None:
-            self.definitions, self.definitions_raw = create_definitions(root_folder, files, runner_filter, parsing_errors)
+            self.definitions, self.definitions_raw = create_definitions(root_folder, files, runner_filter,
+                                                                        parsing_errors)
             report.add_parsing_errors(list(parsing_errors.keys()))
 
             if external_checks_dir:
@@ -82,7 +88,8 @@ class Runner(BaseRunner):
                     if vertex.block_type == BlockType.RESOURCE:
                         report.add_resource(f'{vertex.path}:{vertex.id}')
                 self.graph_manager.save_graph(local_graph)
-                self.definitions, self.breadcrumbs = convert_graph_vertices_to_definitions(local_graph.vertices, root_folder)
+                self.definitions, self.breadcrumbs = convert_graph_vertices_to_definitions(local_graph.vertices,
+                                                                                           root_folder)
 
         # TODO: replace with real graph rendering
         for cf_file in self.definitions.keys():
@@ -95,6 +102,8 @@ class Runner(BaseRunner):
                 )
                 cf_context_parser.evaluate_default_refs()
 
+        self.pbar.initiate(len(self.definitions))
+
         # run checks
         self.check_definitions(root_folder, runner_filter, report)
 
@@ -107,9 +116,8 @@ class Runner(BaseRunner):
 
     def check_definitions(self, root_folder, runner_filter, report):
         for file_abs_path, definition in self.definitions.items():
-
             cf_file = f"/{os.path.relpath(file_abs_path, root_folder)}"
-
+            self.pbar.set_additional_data({'Current File Scanned': cf_file})
             if isinstance(definition, dict) and TemplateSections.RESOURCES in definition.keys():
                 for resource_name, resource in definition[TemplateSections.RESOURCES].items():
                     resource_id = ContextParser.extract_cf_resource_id(resource, resource_name)
@@ -126,29 +134,44 @@ class Runner(BaseRunner):
                             entity = {resource_name: resource}
                             results = cfn_registry.scan(cf_file, entity, skipped_checks, runner_filter)
                             tags = cfn_utils.get_resource_tags(entity)
-                            for check, check_result in results.items():
-                                record = Record(
-                                    check_id=check.id,
-                                    bc_check_id=check.bc_id,
-                                    check_name=check.name,
-                                    check_result=check_result,
-                                    code_block=entity_code_lines,
-                                    file_path=cf_file,
-                                    file_line_range=entity_lines_range,
-                                    resource=resource_id,
-                                    evaluations=variable_evaluations,
-                                    check_class=check.__class__.__module__,
-                                    file_abs_path=file_abs_path,
-                                    entity_tags=tags,
-                                    severity=check.severity
-                                )
+                            if results:
+                                for check, check_result in results.items():
+                                    censored_code_lines = omit_secret_value_from_checks(check, check_result,
+                                                                                        entity_code_lines,
+                                                                                        resource)
+                                    record = Record(
+                                        check_id=check.id,
+                                        bc_check_id=check.bc_id,
+                                        check_name=check.name,
+                                        check_result=check_result,
+                                        code_block=censored_code_lines,
+                                        file_path=cf_file,
+                                        file_line_range=entity_lines_range,
+                                        resource=resource_id,
+                                        evaluations=variable_evaluations,
+                                        check_class=check.__class__.__module__,
+                                        file_abs_path=file_abs_path,
+                                        entity_tags=tags,
+                                        severity=check.severity
+                                    )
 
-                                if CHECKOV_CREATE_GRAPH:
-                                    breadcrumb = self.breadcrumbs.get(record.file_path, {}).get(record.resource)
-                                    if breadcrumb:
-                                        record = GraphRecord(record, breadcrumb)
-                                record.set_guideline(check.guideline)
-                                report.add_record(record=record)
+                                    if CHECKOV_CREATE_GRAPH:
+                                        breadcrumb = self.breadcrumbs.get(record.file_path, {}).get(record.resource)
+                                        if breadcrumb:
+                                            record = GraphRecord(record, breadcrumb)
+                                    record.set_guideline(check.guideline)
+                                    report.add_record(record=record)
+                            else:
+                                # resources without checks, but not existing ones
+                                report.extra_resources.add(
+                                    ExtraResource(
+                                        file_abs_path=str(file_abs_path),
+                                        file_path=cf_file,
+                                        resource=resource_id,
+                                    )
+                                )
+            self.pbar.update()
+        self.pbar.close()
 
     def get_graph_checks_report(self, root_folder: str, runner_filter: RunnerFilter) -> Report:
         report = Report(self.check_type)
