@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import logging
 import subprocess  # nosec
 from pathlib import Path
@@ -10,12 +12,11 @@ import json
 import os
 import time
 
-import requests
-
 from checkov.common.bridgecrew.vulnerability_scanning.integrations.docker_image_scanning import \
     docker_image_scanning_integration
 from checkov.common.bridgecrew.platform_integration import bc_integration
 from checkov.common.util.file_utils import decompress_file_gzip_base64
+from checkov.common.util.http_utils import request_wrapper
 from checkov.common.bridgecrew.platform_key import bridgecrew_dir
 
 TWISTCLI_FILE_NAME = 'twistcli'
@@ -30,7 +31,8 @@ def generate_image_name() -> str:
 def _get_docker_image_name(docker_image_id: str) -> str:
     try:
         docker_client = docker.from_env()
-        return docker_client.images.get(docker_image_id).attrs['RepoDigests'][0].split('@')[0]
+        image_name: str = docker_client.images.get(docker_image_id).attrs['RepoDigests'][0].split('@')[0]
+        return image_name
     except Exception:
         logging.info("Failed to fetch image name.", exc_info=True)
         return generate_image_name()
@@ -60,26 +62,15 @@ class ImageScanner:
             dockerfile_path: Union[str, "os.PathLike[str]"],
             skip_extract_image_name: bool,
     ) -> None:
-        try:
-            if skip_extract_image_name:
-                # Provide a default image name in case the image has not been tagged with a name
-                self.docker_image_name = generate_image_name()
-            else:
-                self.docker_image_name = _get_docker_image_name(docker_image_id)
-            self.dockerfile_content = _get_dockerfile_content(dockerfile_path)
+        if skip_extract_image_name:
+            # Provide a default image name in case the image has not been tagged with a name
+            self.docker_image_name = generate_image_name()
+        else:
+            self.docker_image_name = _get_docker_image_name(docker_image_id)
+        self.dockerfile_content = _get_dockerfile_content(dockerfile_path)
+
+        self.setup_twistcli()
 
-            if self.should_download():
-                if not os.path.exists(bridgecrew_dir):
-                    try:
-                        os.makedirs(bridgecrew_dir)
-                    except FileExistsError:
-                        # In multi-processing, this might meet a race condition
-                        pass
-                self.cleanup_scan()
-                docker_image_scanning_integration.download_twistcli(self.twistcli_path)
-        except Exception:
-            logging.error("Failed to setup docker image scanning", exc_info=True)
-            raise
 
     def cleanup_scan(self) -> None:
         if self.twistcli_path.exists():
@@ -91,15 +82,15 @@ class ImageScanner:
         logging.debug(f"TwistCLI: {command}")
         try:
             subprocess.run([command], check=True, shell=True)  # nosec
-        except Exception:
+        except Exception as exc:
             logging.error("Failed to scan image", exc_info=True)
             self.cleanup_scan()
-            raise Exception(f"Failed to scan image {docker_image_id}")
+            raise Exception(f"Failed to scan image {docker_image_id}") from exc
         self.cleanup_scan()
         logging.info(f'TwistCLI ran successfully on image {docker_image_id}')
 
         with open(DOCKER_IMAGE_SCAN_RESULT_FILE_NAME) as docker_image_scan_result_file:
-            scan_result = json.load(docker_image_scan_result_file)
+            scan_result: dict[str, Any] = json.load(docker_image_scan_result_file)
         return scan_result
 
     def scan(self, docker_image_id: str, dockerfile_path: str, skip_extract_image_name: bool = False) -> int:
@@ -111,7 +102,7 @@ class ImageScanner:
                     twistcli_scan_result=scan_result,
                     bc_platform_integration=bc_integration,
                     bc_api_key=docker_image_scanning_integration.get_bc_api_key(),
-                    file_path=dockerfile_path,
+                    file_path=Path(dockerfile_path),
                     file_content=self.dockerfile_content,
                     docker_image_name=self.docker_image_name,
                 )
@@ -125,13 +116,11 @@ class ImageScanner:
 
     @staticmethod
     def get_scan_results_from_cache(image_id: str) -> Dict[str, Any]:
-        image_id = f"sha256:{image_id}" if not image_id.startswith("sha256:") else image_id
         image_id_encode = quote_plus(image_id)
-        response = requests.request(
+        response = request_wrapper(
             "GET", f"{bc_integration.api_url}/api/v1/vulnerabilities/scan-results/{image_id_encode}",
-            headers=bc_integration.get_default_headers("GET")
+            headers=bc_integration.get_default_headers("GET"), should_call_raise_for_status=True
         )
-        response.raise_for_status()
         response_json = response.json()
         output_type = response_json["outputType"]
 
@@ -142,11 +131,12 @@ class ImageScanner:
             return {}
 
         elif output_type == "Result":
-            return json.loads(
+            result: dict[str, Any] = json.loads(
                 decompress_file_gzip_base64(
                     response_json["outputData"]
                 )
             )
+            return result
         logging.info(f"Got an empty result for image={image_id}")
         return {}
 
@@ -157,5 +147,20 @@ class ImageScanner:
         file_age = (time.time() - last_modification.st_mtime)
         return file_age >= int(os.getenv("CHECKOV_EXPIRATION_TIME_IN_SEC", CHECKOV_SEC_IN_WEEK))
 
+    def setup_twistcli(self) -> None:
+        try:
+            if self.should_download():
+                if not os.path.exists(bridgecrew_dir):
+                    try:
+                        os.makedirs(bridgecrew_dir)
+                    except FileExistsError:
+                        # In multi-processing, this might meet a race condition
+                        pass
+                self.cleanup_scan()
+                docker_image_scanning_integration.download_twistcli(image_scanner.twistcli_path)
+        except Exception:
+            logging.error("Failed to setup docker image scanning", exc_info=True)
+            raise
+
 
 image_scanner = ImageScanner()
