@@ -1,6 +1,9 @@
+from __future__ import annotations
+
+import logging
 import os
 from pathlib import Path
-from typing import Dict, Any
+from typing import Any
 
 from checkov.common.bridgecrew.platform_integration import BcPlatformIntegration
 from checkov.common.bridgecrew.vulnerability_scanning.integrations.twistcli import TwistcliIntegration
@@ -10,7 +13,7 @@ from checkov.common.util.str_utils import removeprefix
 class DockerImageScanningIntegration(TwistcliIntegration):
     async def report_results_async(
         self,
-        twistcli_scan_result: Dict[str, Any],
+        twistcli_scan_result: dict[str, Any],
         bc_platform_integration: BcPlatformIntegration,
         bc_api_key: str,
         file_path: Path,
@@ -29,7 +32,7 @@ class DockerImageScanningIntegration(TwistcliIntegration):
     # make sure to remove it only after validating it isn't used from the platform
     def report_results(
         self,
-        twistcli_scan_result: Dict[str, Any],
+        twistcli_scan_result: dict[str, Any],
         file_path: Path,
         **kwargs: Any,
     ) -> None:
@@ -40,16 +43,20 @@ class DockerImageScanningIntegration(TwistcliIntegration):
             docker_image_name=kwargs['docker_image_name'],
         )
 
-    def create_report(
+    def create_report(  # type:ignore[override]
         self,
-        twistcli_scan_result: Dict[str, Any],
+        twistcli_scan_result: dict[str, Any],
         bc_platform_integration: BcPlatformIntegration,
         file_path: Path,
         file_content: str,
         docker_image_name: str,
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
+        if not bc_platform_integration.bc_source:
+            logging.error("Source was not set")
+            return {}
+
         results_dict = self._get_results_dict(twistcli_scan_result)
-        payload = {
+        payload: dict[str, Any] = {
             "dockerImageName": docker_image_name,
             "dockerFilePath": removeprefix(str(file_path), os.getenv("BC_ROOT_DIR", "")),
             "dockerFileContent": file_content,
@@ -65,15 +72,16 @@ class DockerImageScanningIntegration(TwistcliIntegration):
         return payload
 
     @staticmethod
-    def _get_results_dict(twistcli_scan_result: Dict[str, Any]) -> Dict[str, Any]:
+    def _get_results_dict(twistcli_scan_result: dict[str, Any]) -> dict[str, Any]:
         try:
             results = twistcli_scan_result["results"]
             # we expect that there is exactly 1 scanned dokcer-image.
             if len(results) != 1:
                 raise Exception(f'expected length of \"results\": 1. found: {len(results)}', results)
-        except KeyError:
-            raise Exception("the key \"results\" expected to be existing in:", twistcli_scan_result)
-        return results[0]
+        except KeyError as exc:
+            raise Exception("the key \"results\" expected to be existing in:", twistcli_scan_result) from exc
+        result: dict[str, Any] = results[0]
+        return result
 
 
 docker_image_scanning_integration = DockerImageScanningIntegration()
