@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+import os
 import logging
 import platform
 import stat
@@ -6,22 +9,19 @@ from pathlib import Path
 from typing import Dict, Any, List
 from datetime import datetime, timedelta
 
-import aiohttp
 from checkov.common.bridgecrew.platform_integration import bc_integration, BcPlatformIntegration
 from checkov.common.util.data_structures_utils import merge_dicts
-from checkov.common.util.http_utils import get_default_post_headers, request_wrapper
+from checkov.common.util.http_utils import get_default_post_headers, request_wrapper, aiohttp_client_session_wrapper
 
 
 class TwistcliIntegration(ABC):
-    vulnerabilities_base_url = f"{bc_integration.api_url}/api/v1/vulnerabilities"
-    vulnerabilities_save_results_url = f"{vulnerabilities_base_url}/results"
-    twictcli_base_url = f"{vulnerabilities_base_url}/twistcli"
+    vulnerabilities_base_path = "/api/v1/vulnerabilities"  # noqa: CCE003  # a static attribute
 
     def get_bc_api_key(self) -> str:
         return bc_integration.get_auth_token()
 
     def get_proxy_address(self) -> str:
-        return f"{self.vulnerabilities_base_url}/docker-images/twistcli/proxy"
+        return f"{bc_integration.api_url}{self.vulnerabilities_base_path}/docker-images/twistcli/proxy"
 
     def download_twistcli(self, cli_file_name: Path) -> None:
         # backwards compatibility, should be removed in a later stage
@@ -29,7 +29,8 @@ class TwistcliIntegration(ABC):
 
         os_type = platform.system().lower()
 
-        response = request_wrapper("GET", f"{self.twictcli_base_url}?os={os_type}",
+        response = request_wrapper("GET",
+                                   f"{bc_integration.api_url}{self.vulnerabilities_base_path}/twistcli?os={os_type}",
                                    headers=bc_integration.get_default_headers("GET"),
                                    should_call_raise_for_status=True)
 
@@ -47,7 +48,7 @@ class TwistcliIntegration(ABC):
             **kwargs,
         )
 
-        request_wrapper("POST", self.vulnerabilities_save_results_url,
+        request_wrapper("POST", f"{bc_integration.api_url}{self.vulnerabilities_base_path}/results",
                         headers=bc_integration.get_default_headers("POST"),
                         json=payload, should_call_raise_for_status=True)
 
@@ -61,6 +62,10 @@ class TwistcliIntegration(ABC):
     ) -> int:
         logging.info(f"Start to send report for package file {file_path}")
 
+        if not bc_platform_integration.bc_source:
+            logging.error("Source was not set")
+            return 1
+
         payload = self.create_report(
             twistcli_scan_result=twistcli_scan_result,
             bc_platform_integration=bc_platform_integration,
@@ -71,23 +76,24 @@ class TwistcliIntegration(ABC):
             get_default_post_headers(bc_platform_integration.bc_source, bc_platform_integration.bc_source_version),
             {"Authorization": bc_api_key},
         )
+        url = f"{bc_integration.api_url}{self.vulnerabilities_base_path}/results"
 
-        async with aiohttp.ClientSession(connector=aiohttp.TCPConnector(resolver=aiohttp.AsyncResolver())) as session:
-            async with session.post(
-                url=self.vulnerabilities_save_results_url, headers=headers, json=payload
-            ) as response:
-                content = await response.text()
+        logging.info(f"[twistcli](report_results_async) - reporting results to the server for the file \'{file_path}\'")
+        status: int = await aiohttp_client_session_wrapper(url, headers, payload)
 
-            if response.ok:
-                logging.info(f"Successfully send report for package file {file_path}")
-                return 0
-            else:
-                logging.error(f"Failed to send report for package file {file_path}")
-                logging.error(f"Status code: {response.status}, Reason: {response.reason}, Content: {content}")
-                return 1
+        if status == 1:
+            logging.error(f"[twistcli](report_results_async) - Failed to send report for package file {file_path}"
+                          f"\nerror message appears above")
+        return status
 
     @abstractmethod
-    def create_report(self, **kwargs: Any) -> Dict[str, Any]:
+    def create_report(
+        self,
+        twistcli_scan_result: dict[str, Any],
+        bc_platform_integration: BcPlatformIntegration,
+        file_path: Path,
+        **kwargs: Any,
+    ) -> dict[str, Any]:
         pass
 
     @staticmethod
@@ -120,4 +126,4 @@ class TwistcliIntegration(ABC):
                 "licenses": package.get("licenses") or [],
             }
             for package in scan_results.get("packages") or []
-        ]
\ No newline at end of file
+        ]
