@@ -88,13 +88,17 @@ class BaseCheck(metaclass=MultiSignatureMeta):
 
     @multi_signature()
     @abstractmethod
-    def scan_entity_conf(self, conf: Dict[str, Any], entity_type: str) -> CheckResult:
+    def scan_entity_conf(self, conf: dict[str, Any], entity_type: str) -> CheckResult | tuple[CheckResult, dict[str, Any]]:
         raise NotImplementedError()
 
     @classmethod
     @scan_entity_conf.add_signature(args=["self", "conf"])
-    def _scan_entity_conf_self_conf(cls, wrapped: Callable[..., CheckResult]) -> Callable[..., CheckResult]:
-        def wrapper(self: "BaseCheck", conf: Dict[str, Any], entity_type: Optional[str] = None) -> CheckResult:
+    def _scan_entity_conf_self_conf(
+        cls, wrapped: Callable[..., CheckResult | tuple[CheckResult, dict[str, Any]]]
+    ) -> Callable[..., CheckResult | tuple[CheckResult, dict[str, Any]]]:
+        def wrapper(
+            self: "BaseCheck", conf: Dict[str, Any], entity_type: Optional[str] = None
+        ) -> CheckResult | tuple[CheckResult, dict[str, Any]]:
             # keep default argument for entity_type so old code, that doesn't set it, will work.
             return wrapped(self, conf)
 
