@@ -9,12 +9,9 @@ logger = logging.getLogger(__name__)
 
 
 class ContainsAttributeSolver(BaseAttributeSolver):
-    operator = Operators.CONTAINS
+    operator = Operators.CONTAINS  # noqa: CCE003  # a static attribute
 
-    def __init__(self, resource_types: List[str], attribute: Optional[str], value: Any) -> None:
-        super().__init__(resource_types=resource_types, attribute=attribute, value=value)
-
-    def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:
+    def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:  # type:ignore[override]
         att = vertex.get(attribute, "{}")  # type:ignore[arg-type]  # due to attribute can be None
         if isinstance(att, str):
             try:
