@@ -6,14 +6,15 @@ from checkov.common.util.type_forcers import force_float
 
 
 class GreaterThanOrEqualAttributeSolver(BaseAttributeSolver):
-    operator = Operators.GREATER_THAN_OR_EQUAL
+    operator = Operators.GREATER_THAN_OR_EQUAL  # noqa: CCE003  # a static attribute
 
-    def __init__(self, resource_types: List[str], attribute: Optional[str], value: Any) -> None:
-        super().__init__(resource_types=resource_types, attribute=attribute, value=value)
-
-    def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:
+    def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:  # type:ignore[override]
 
         vertex_attr = vertex.get(attribute)  # type:ignore[arg-type]  # due to attribute can be None
+        # if this value contains an underendered variable, then we cannot evaluate the check,
+        # so return True (since we cannot return UNKNOWN)
+        if self._is_variable_dependant(vertex_attr, vertex['source_']):
+            return True
         attr_float = force_float(vertex_attr)
         value_float = force_float(self.value)
 
