@@ -7,16 +7,12 @@ from checkov.common.checks_infra.solvers.attribute_solvers.base_attribute_solver
 
 
 class RegexMatchAttributeSolver(BaseAttributeSolver):
-    operator = Operators.REGEX_MATCH
+    operator = Operators.REGEX_MATCH  # noqa: CCE003  # a static attribute
 
-    def __init__(self, resource_types: List[str], attribute: Optional[str], value: Any) -> None:
-        super().__init__(resource_types=resource_types,
-                         attribute=attribute, value=value)
-
-    def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:
+    def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:  # type:ignore[override]
         attr = vertex.get(attribute)  # type:ignore[arg-type]  # due to attribute can be None
         try:
             return re.match(str(self.value), str(attr)) is not None
         except re.error as e:
-            logging.warn(f'failed to run regex {self.value} for attribute: {attr}, ', e)
+            logging.warning(f'failed to run regex {self.value} for attribute: {attr}, {str(e)}')
             return False
