@@ -5,11 +5,14 @@ from checkov.common.checks_infra.solvers.attribute_solvers.base_attribute_solver
 
 
 class StartingWithAttributeSolver(BaseAttributeSolver):
-    operator = Operators.STARTING_WITH
+    operator = Operators.STARTING_WITH  # noqa: CCE003  # a static attribute
 
-    def __init__(self, resource_types: List[str], attribute: Optional[str], value: Any) -> None:
-        super().__init__(resource_types=resource_types, attribute=attribute, value=value)
-
-    def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:
+    def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:  # type:ignore[override]
         attr = vertex.get(attribute)  # type:ignore[arg-type]  # due to attribute can be None
+
+        # if this value contains an underendered variable, then we cannot evaluate the check,
+        # so return True (since we cannot return UNKNOWN)
+        if self._is_variable_dependant(attr, vertex["source_"]):
+            return True
+
         return isinstance(attr, str) and attr.startswith(self.value)
