@@ -5,13 +5,9 @@ from checkov.common.checks_infra.solvers.attribute_solvers.base_attribute_solver
 
 
 class SubsetAttributeSolver(BaseAttributeSolver):
-    operator = Operators.SUBSET
+    operator = Operators.SUBSET  # noqa: CCE003  # a static attribute
 
-    def __init__(self, resource_types: List[str], attribute: Optional[str], value: Any) -> None:
-        super().__init__(resource_types=resource_types,
-                         attribute=attribute, value=SubsetAttributeSolver.to_set(value))
-
-    def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:
+    def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:  # type:ignore[override]
         attr_val = SubsetAttributeSolver.to_set(vertex.get(attribute))  # type:ignore[arg-type]  # due to attribute can be None
         return attr_val.issubset(self.value)
 
