@@ -77,7 +77,7 @@ class BaseConnectionSolver(BaseSolver):
 
         return graph_connector.subgraph(resource_nodes)
 
-    def get_operation(self, graph_connector: DiGraph) -> Tuple[List[Dict[str, Any]], List[Dict[str, Any]]]:
+    def get_operation(self, graph_connector: DiGraph) -> Tuple[List[Dict[str, Any]], List[Dict[str, Any]]]:  # type:ignore[override]
         raise NotImplementedError
 
     def _get_operation(self, *args: Any, **kwargs: Any) -> Any:
