@@ -10,7 +10,7 @@ from checkov.common.checks_infra.solvers.complex_solvers.base_complex_solver imp
 from checkov.common.checks_infra.solvers.connections_solvers.base_connection_solver import BaseConnectionSolver
 from checkov.common.checks_infra.solvers.filter_solvers.base_filter_solver import BaseFilterSolver
 
-from checkov.terraform.graph_builder.graph_components.attribute_names import CustomAttributes
+from checkov.common.graph.graph_builder.graph_components.attribute_names import CustomAttributes
 
 
 class ComplexConnectionSolver(BaseConnectionSolver):
@@ -32,7 +32,7 @@ class ComplexConnectionSolver(BaseConnectionSolver):
 
     @staticmethod
     def filter_duplicates(checks: List[Dict[str, Any]]) -> List[Dict[str, Any]]:
-        return list({check[CustomAttributes.ID]: check for check in checks}.values())
+        return list({(check[CustomAttributes.ID], check[CustomAttributes.FILE_PATH]): check for check in checks}.values())
 
     def filter_results(
         self, passed: List[Dict[str, Any]], failed: List[Dict[str, Any]]
