@@ -9,12 +9,12 @@ from checkov.common.graph.graph_builder.graph_components.attribute_names import
 
 
 class OrConnectionSolver(ComplexConnectionSolver):
-    operator = Operators.OR
+    operator = Operators.OR  # noqa: CCE003  # a static attribute
 
     def __init__(self, solvers: Optional[List[BaseSolver]], operator: str) -> None:
         super().__init__(solvers, operator)
 
-    def get_operation(self, graph_connector: DiGraph) -> Tuple[List[Dict[str, Any]], List[Dict[str, Any]]]:
+    def get_operation(self, graph_connector: DiGraph) -> Tuple[List[Dict[str, Any]], List[Dict[str, Any]]]:  # type:ignore[override]
         passed, failed = self.run_attribute_solvers(graph_connector)
         failed = OrConnectionSolver._filter_failed(failed, passed)
         connection_solvers = [sub_solver for sub_solver in self.solvers if isinstance(sub_solver, BaseConnectionSolver)]
