@@ -1,4 +1,6 @@
-from typing import List, Any, Dict, Callable, Tuple
+from __future__ import annotations
+
+from typing import Any, Callable
 
 from networkx import DiGraph
 
@@ -7,12 +9,12 @@ from checkov.common.graph.checks_infra.solvers.base_solver import BaseSolver
 
 
 class BaseFilterSolver(BaseSolver):
-    def __init__(self, resource_types: List[str], attribute: str, value: Any) -> None:
+    def __init__(self, resource_types: list[str], attribute: str | None, value: Any) -> None:
         super().__init__(SolverType.FILTER)
         self.resource_types = resource_types
         self.attribute = attribute
         self.value = value
-        self.vertices: List[Dict[str, Any]] = []
+        self.vertices: list[dict[str, Any]] = []
 
     def get_operation(self, *args: Any, **kwargs: Any) -> bool:
         raise NotImplementedError()
@@ -20,5 +22,5 @@ class BaseFilterSolver(BaseSolver):
     def _get_operation(self, *args: Any, **kwargs: Any) -> Callable[..., bool]:
         raise NotImplementedError()
 
-    def run(self, graph_connector: DiGraph) -> Tuple[List[Dict[str, Any]], List[Dict[str, Any]]]:
+    def run(self, graph_connector: DiGraph) -> tuple[list[dict[str, Any]], list[dict[str, Any]]]:
         raise NotImplementedError()
