@@ -24,13 +24,14 @@ def loads(content: str) -> list[dict[str, Any]]:
     return template
 
 
-def load(filename: Path) -> tuple[list[dict[str, Any]], list[tuple[int, str]]]:
+def load(filename: str | Path, content: str | None = None) -> tuple[list[dict[str, Any]], list[tuple[int, str]]]:
     """
     Load the given YAML file
     """
 
-    file_path = filename if isinstance(filename, Path) else Path(filename)
-    content = file_path.read_text()
+    if not content:
+        file_path = filename if isinstance(filename, Path) else Path(filename)
+        content = file_path.read_text()
 
     file_lines = [(idx + 1, line) for idx, line in enumerate(content.splitlines(keepends=True))]
 
@@ -41,7 +42,7 @@ def load(filename: Path) -> tuple[list[dict[str, Any]], list[tuple[int, str]]]:
 
 class SafeLineLoader(SafeLoader):
     def construct_mapping(self, node: MappingNode, deep: bool = False) -> dict[str, Any]:
-        mapping = super().construct_mapping(node, deep=deep)
+        mapping: dict[str, Any] = super().construct_mapping(node, deep=deep)  # type:ignore[no-untyped-call]  # sadly it is untyped
         # Add 1 so line numbering starts at 1
         # mapping['__line__'] = node.start_mark.line + 1
         mapping['__startline__'] = node.start_mark.line + 1
