@@ -1,10 +1,14 @@
 from __future__ import annotations
 
 import itertools
+import logging
 import os
 import re
 from abc import ABC, abstractmethod
-from typing import List, Dict, Optional, Any, Union, TYPE_CHECKING, Iterable
+from collections.abc import Iterable
+from typing import List, Dict, Any, TYPE_CHECKING, TypeVar, Generic
+
+from checkov.common.util.tqdm_utils import ProgressBar
 
 from checkov.common.graph.checks_infra.base_check import BaseGraphCheck
 from checkov.common.output.report import Report
@@ -13,7 +17,9 @@ from checkov.runner_filter import RunnerFilter
 if TYPE_CHECKING:
     from checkov.common.checks_infra.registry import Registry
     from checkov.common.graph.checks_infra.registry import BaseRegistry
-    from checkov.common.graph.graph_manager import GraphManager
+    from checkov.common.graph.graph_manager import GraphManager  # noqa
+
+_GraphManager = TypeVar("_GraphManager", bound="GraphManager[Any]|None")
 
 
 def strtobool(val: str) -> int:
@@ -39,18 +45,19 @@ IGNORE_HIDDEN_DIRECTORY_ENV = strtobool(os.getenv("CKV_IGNORE_HIDDEN_DIRECTORIES
 ignored_directories = IGNORED_DIRECTORIES_ENV.split(",")
 
 
-class BaseRunner(ABC):
+class BaseRunner(ABC, Generic[_GraphManager]):
     check_type = ""
     definitions = None
     context: dict[str, dict[str, Any]] | None = None
     breadcrumbs = None
     external_registries: list[BaseRegistry] | None = None
-    graph_manager: GraphManager | None = None
+    graph_manager: _GraphManager | None = None
     graph_registry: Registry | None = None
 
-    def __init__(self, file_extensions: Optional[Iterable[str]] = [], file_names: Optional[Iterable[str]] = []):
-        self.file_extensions = file_extensions
-        self.file_names = file_names
+    def __init__(self, file_extensions: Iterable[str] | None = None, file_names: Iterable[str] | None = None):
+        self.file_extensions = file_extensions or []
+        self.file_names = file_names or []
+        self.pbar = ProgressBar(self.check_type)
 
     @abstractmethod
     def run(
@@ -80,31 +87,42 @@ class BaseRunner(ABC):
 
     def set_external_data(
             self,
-            definitions: Optional[Dict[str, Dict[str, Any]]],
-            context: Optional[Dict[str, Dict[str, Any]]],
-            breadcrumbs: Optional[Dict[str, Dict[str, Any]]],
-            **kwargs
+            definitions: dict[str, dict[str, Any]] | None,
+            context: dict[str, dict[str, Any]] | None,
+            breadcrumbs: dict[str, dict[str, Any]] | None,
+            **kwargs: Any,
     ) -> None:
         self.definitions = definitions
         self.context = context
         self.breadcrumbs = breadcrumbs
 
-    def load_external_checks(self, external_checks_dir: List[str]):
+    def load_external_checks(self, external_checks_dir: List[str]) -> None:
         pass
 
-    def get_graph_checks_report(self, root_folder: str, runner_filter: RunnerFilter):
+    def get_graph_checks_report(self, root_folder: str, runner_filter: RunnerFilter) -> Report:
         pass
 
     def run_graph_checks_results(self, runner_filter: RunnerFilter) -> Dict[BaseGraphCheck, List[Dict[str, Any]]]:
         checks_results: Dict[BaseGraphCheck, List[Dict[str, Any]]] = {}
+
+        if not self.graph_manager or not self.graph_registry:
+            # should not happen
+            logging.warning("Graph components were not initialized")
+            return checks_results
+
         for r in itertools.chain(self.external_registries or [], [self.graph_registry]):
             r.load_checks()
-            registry_results = r.run_checks(self.graph_manager.get_reader_endpoint(), runner_filter)
+            registry_results = r.run_checks(self.graph_manager.get_reader_endpoint(), runner_filter)  # type:ignore[union-attr]
             checks_results = {**checks_results, **registry_results}
         return checks_results
 
 
-def filter_ignored_paths(root_dir: str, names: List[Union[str, os.DirEntry]], excluded_paths: Optional[List[str]], included_paths: Optional[List[str]] = None) -> None:
+def filter_ignored_paths(
+    root_dir: str,
+    names: list[str] | list[os.DirEntry[str]],
+    excluded_paths: list[str] | None,
+    included_paths: Iterable[str] | None = None
+) -> None:
     # we need to handle legacy logic, where directories to skip could be specified using the env var (default value above)
     # or a directory starting with '.'; these look only at directory basenames, not relative paths.
     #
@@ -126,7 +144,7 @@ def filter_ignored_paths(root_dir: str, names: List[Union[str, os.DirEntry]], ex
     # mostly this will just remove those problematic directories hardcoded above.
     included_paths = included_paths or []
     for entry in list(names):
-        path = entry if type(entry) == str else entry.name
+        path = entry.name if isinstance(entry, os.DirEntry) else entry
         if path in ignored_directories:
             safe_remove(names, entry)
         if path.startswith(".") and IGNORE_HIDDEN_DIRECTORY_ENV and path not in included_paths:
@@ -138,11 +156,11 @@ def filter_ignored_paths(root_dir: str, names: List[Union[str, os.DirEntry]], ex
     if excluded_paths:
         compiled = [re.compile(p.replace(".terraform", r"\.terraform")) for p in excluded_paths]
         for entry in list(names):
-            path = entry if type(entry) == str else entry.name
+            path = entry.name if isinstance(entry, os.DirEntry) else entry
             if any(pattern.search(os.path.join(root_dir, path)) for pattern in compiled):
-                names.remove(entry)
+                safe_remove(names, entry)
 
 
-def safe_remove(names, path):
+def safe_remove(names: list[Any], path: Any) -> None:
     if path in names:
         names.remove(path)
