@@ -44,24 +44,30 @@ class BaseVCSDAL:
         if ca_certificate:
             os.environ['REQUESTS_CA_BUNDLE'] = ca_certificate
             try:
+                parsed_url = urllib3.util.parse_url(os.environ['https_proxy']) # type:ignore[no-untyped-call]
                 self.http = urllib3.ProxyManager(os.environ['https_proxy'], cert_reqs='REQUIRED',
-                                                 ca_certs=ca_certificate)
+                                                 ca_certs=ca_certificate,
+                                                 proxy_headers=urllib3.make_headers(proxy_basic_auth=parsed_url.auth)) # type:ignore[no-untyped-call]
             except KeyError:
                 self.http = urllib3.PoolManager(cert_reqs='REQUIRED', ca_certs=ca_certificate)
         else:
             try:
-                self.http = urllib3.ProxyManager(os.environ['https_proxy'])
+                parsed_url = urllib3.util.parse_url(os.environ['https_proxy']) # type:ignore[no-untyped-call]
+                self.http = urllib3.ProxyManager(os.environ['https_proxy'],
+                                                 proxy_headers=urllib3.make_headers(proxy_basic_auth=parsed_url.auth)) # type:ignore[no-untyped-call]
             except KeyError:
                 self.http = urllib3.PoolManager()
 
-    def _request(self, endpoint: str) -> dict[str, Any] | None:
+    def _request(self, endpoint: str, allowed_status_codes: list[int]) -> dict[str, Any] | None:
+        if allowed_status_codes is None:
+            allowed_status_codes = [200]
         if not self.token:
             return None
         url_endpoint = f"{self.api_url}/{endpoint}"
         try:
             headers = self._headers()
             request = self.http.request("GET", url_endpoint, headers=headers)
-            if request.status == 200:
+            if request.status in allowed_status_codes:
                 data = json.loads(request.data.decode("utf8"))
                 if isinstance(data, dict) and 'errors' in data.keys():
                     return None
