@@ -16,7 +16,7 @@ class Registry(BaseCheckRegistry):
                     if check.id in [x['id'] for x in skipped_checks]:
                         skip_info = [x for x in skipped_checks if x['id'] == check.id][0]
 
-                    if runner_filter.should_run_check(check.id, check.bc_id):
+                    if runner_filter.should_run_check(check):
                         entity_name = instruction
                         entity_type = instruction
                         entity_configuration = entity[instruction]
@@ -29,7 +29,7 @@ class Registry(BaseCheckRegistry):
                 if check.id in [x['id'] for x in skipped_checks]:
                     skip_info = [x for x in skipped_checks if x['id'] == check.id][0]
 
-            if runner_filter.should_run_check(check.id, check.bc_id):
+            if runner_filter.should_run_check(check):
                 entity_name = scanned_file
                 entity_type = "*"
                 entity_configuration = entity
