@@ -24,7 +24,7 @@ class ReferenceLatestTag(BaseDockerfileCheck):
                 base_image = multi_stage[1]
                 stages.append(multi_stage[2])
 
-            if ":" not in base_image and base_image not in stages:
+            if ":" not in base_image and base_image not in stages and base_image != "scratch":
                 return CheckResult.FAILED, content
             elif base_image.endswith(":latest"):
                 return CheckResult.FAILED, content
