@@ -43,7 +43,7 @@ class Runner(YamlRunner):
         return self.block_type_registries["jobs"]
 
     def _parse_file(
-        self, f: str
+        self, f: str, file_content: str | None = None
     ) -> tuple[dict[str, Any] | list[dict[str, Any]], list[tuple[int, str]]] | None:
         # EDIT" add conditional here to ensure this file is something we should parse.
         # Below is this example for github actions
