@@ -2,7 +2,6 @@ from checkov.common.checks.base_check_registry import BaseCheckRegistry
 
 
 class Registry(BaseCheckRegistry):
-
     def extract_entity_details(self, entity):
         kind = entity["kind"]
         conf = entity
@@ -18,7 +17,7 @@ class Registry(BaseCheckRegistry):
                 if check.id in [x['id'] for x in skipped_checks]:
                     skip_info = [x for x in skipped_checks if x['id'] == check.id][0]
 
-            if self._should_run_scan(check.id, entity_configuration, runner_filter, check.bc_id):
+            if self._should_run_scan(check, entity_configuration, runner_filter):
                 self.logger.debug("Running check: {} on file {}".format(check.name, scanned_file))
 
                 result = check.run(scanned_file=scanned_file, entity_configuration=entity_configuration,
@@ -27,16 +26,16 @@ class Registry(BaseCheckRegistry):
         return results
 
     @staticmethod
-    def _should_run_scan(check_id, entity_configuration, runner_filter, bc_id=None):
+    def _should_run_scan(check, entity_configuration, runner_filter):
         check_id_allowlist = runner_filter.checks
         check_id_denylist = runner_filter.skip_checks
-        if check_id_allowlist:
+        if check_id_allowlist or runner_filter.check_threshold:
             # Allow list provides namespace-only allows, check-only allows, or both
             # If namespaces not specified, all namespaces are scanned
             # If checks not specified, all checks are scanned
             run_check = False
             allowed_namespaces = [string for string in check_id_allowlist if ("CKV_" not in string and "BC_" not in string)]
-            if not any(("CKV_" in check or "BC_" in check) for check in check_id_allowlist):
+            if not any(("CKV_" in check or "BC_" in check) for check in check_id_allowlist) and not runner_filter.check_threshold:
                 if "metadata" in entity_configuration and "namespace" in entity_configuration["metadata"]:
                     if entity_configuration["metadata"]["namespace"] in allowed_namespaces:
                         run_check = True
@@ -47,7 +46,7 @@ class Registry(BaseCheckRegistry):
                     if "default" in allowed_namespaces:
                         run_check = True
             else:
-                if runner_filter.should_run_check(check_id, bc_id):
+                if runner_filter.should_run_check(check=check):
                     if allowed_namespaces:
                         # Check if namespace in allowed namespaces
                         if "metadata" in entity_configuration and "namespace" in entity_configuration["metadata"]:
@@ -64,7 +63,7 @@ class Registry(BaseCheckRegistry):
                         run_check = True
             if run_check:
                 return True
-        elif check_id_denylist:
+        elif check_id_denylist or runner_filter.skip_check_threshold:
             namespace_skip = False
             if "metadata" in entity_configuration and "namespace" in entity_configuration["metadata"]:
                 if entity_configuration["metadata"]["namespace"] in check_id_denylist:
@@ -75,7 +74,7 @@ class Registry(BaseCheckRegistry):
             else:
                 if "default" in check_id_denylist:
                     namespace_skip = True
-            if runner_filter.should_run_check(check_id, bc_id) and not namespace_skip:
+            if runner_filter.should_run_check(check=check) and not namespace_skip:
                 return True
         else:
             return True
