@@ -1,14 +1,17 @@
+from __future__ import annotations
+
 import logging
 import operator
 import os
 from functools import reduce
-from typing import Type, Optional, List
+from typing import Type, Any, TYPE_CHECKING
 
 from checkov.common.checks_infra.registry import get_graph_checks_registry
 from checkov.common.graph.checks_infra.registry import BaseRegistry
 from checkov.common.graph.db_connectors.networkx.networkx_db_connector import NetworkxConnector
 from checkov.common.graph.graph_builder import CustomAttributes
 from checkov.common.graph.graph_builder.local_graph import LocalGraph
+from checkov.common.output.extra_resource import ExtraResource
 from checkov.common.graph.graph_manager import GraphManager
 from checkov.common.output.record import Record
 from checkov.common.output.report import Report, merge_reports, CheckType
@@ -16,22 +19,34 @@ from checkov.common.runners.base_runner import BaseRunner, CHECKOV_CREATE_GRAPH
 from checkov.kubernetes.checks.resource.registry import registry
 from checkov.kubernetes.graph_builder.local_graph import KubernetesLocalGraph
 from checkov.kubernetes.graph_manager import KubernetesGraphManager
-from checkov.kubernetes.kubernetes_utils import create_definitions, build_definitions_context, get_skipped_checks, get_resource_id
+from checkov.kubernetes.kubernetes_utils import (
+    create_definitions,
+    build_definitions_context,
+    get_skipped_checks,
+    get_resource_id,
+    K8_POSSIBLE_ENDINGS,
+)
 from checkov.runner_filter import RunnerFilter
 
+if TYPE_CHECKING:
+    from checkov.common.graph.checks_infra.base_check import BaseGraphCheck
+
 
 class Runner(BaseRunner):
+    check_type = CheckType.KUBERNETES  # noqa: CCE003  # a static attribute
+
     def __init__(
         self,
         graph_class: Type[LocalGraph] = KubernetesLocalGraph,
-        db_connector: NetworkxConnector = NetworkxConnector(),
+        db_connector: NetworkxConnector | None = None,
         source: str = "Kubernetes",
-        graph_manager: Optional[GraphManager] = None,
-        external_registries: Optional[List[BaseRegistry]] = None
+        graph_manager: GraphManager | None = None,
+        external_registries: list[BaseRegistry] | None = None,
     ) -> None:
-        super().__init__(file_extensions=['.yml', '.yaml'])
+        db_connector = db_connector or NetworkxConnector()
+
+        super().__init__(file_extensions=K8_POSSIBLE_ENDINGS)
         self.external_registries = [] if external_registries is None else external_registries
-        self.check_type = CheckType.KUBERNETES
         self.graph_class = graph_class
         self.graph_manager = \
             graph_manager if graph_manager else KubernetesGraphManager(source=source, db_connector=db_connector)
@@ -40,7 +55,18 @@ class Runner(BaseRunner):
         self.definitions_raw = {}
         self.report_mutator_data = None
 
-    def run(self, root_folder, external_checks_dir=None, files=None, runner_filter=RunnerFilter(), collect_skip_comments=True, helmChart=None):
+    def run(
+        self,
+        root_folder: str | None,
+        external_checks_dir: list[str] | None = None,
+        files: list[str] | None = None,
+        runner_filter: RunnerFilter | None = None,
+        collect_skip_comments: bool = True,
+    ) -> Report:
+        runner_filter = runner_filter or RunnerFilter()
+        if not runner_filter.show_progress_bar:
+            self.pbar.turn_off_progress_bar()
+
         report = Report(self.check_type)
         if self.context is None or self.definitions is None:
             if files or root_folder:
@@ -66,17 +92,20 @@ class Runner(BaseRunner):
                     report.add_resource(f'{file_abs_path}:{vertex.id}')
                 self.graph_manager.save_graph(local_graph)
                 self.definitions = local_graph.definitions
-
-        report = self.check_definitions(root_folder, runner_filter, report, collect_skip_comments=collect_skip_comments, helmChart=helmChart)
+        self.pbar.initiate(len(self.definitions))
+        report = self.check_definitions(root_folder, runner_filter, report, collect_skip_comments=collect_skip_comments)
 
         if CHECKOV_CREATE_GRAPH:
-            graph_report = self.get_graph_checks_report(root_folder, runner_filter, helmChart=helmChart)
+            graph_report = self.get_graph_checks_report(root_folder, runner_filter)
             merge_reports(report, graph_report)
 
         return report
 
-    def check_definitions(self, root_folder, runner_filter, report, collect_skip_comments=True, helmChart=None,):
+    def check_definitions(
+        self, root_folder: str | None, runner_filter: RunnerFilter, report: Report, collect_skip_comments: bool = True
+    ) -> Report:
         for k8_file in self.definitions.keys():
+            self.pbar.set_additional_data({'Current File Scanned': os.path.relpath(k8_file, root_folder)})
             # There are a few cases here. If -f was used, there could be a leading / because it's an absolute path,
             # or there will be no leading slash; root_folder will always be none.
             # If -d is used, root_folder will be the value given, and -f will start with a / (hardcoded above).
@@ -87,7 +116,7 @@ class Runner(BaseRunner):
             for entity_conf in self.definitions[k8_file]:
                 entity_type = entity_conf.get("kind")
 
-                # Skip Kustomization Templates. 
+                # Skip Kustomization Templates.
                 # Should be handled by Kusomize framework handler when it finds kustomization.yaml files.
                 # TODO: FUTURE: Potentially call the framework if we find items here that aren't in a file called kustomization.yaml - validate this edge case.
                 if entity_type == "Kustomization":
@@ -100,10 +129,11 @@ class Runner(BaseRunner):
                 variable_evaluations = {}
 
                 report = self.mutateKubernetesResults(results, report, k8_file, k8_file_path, file_abs_path, entity_conf, variable_evaluations)
-
+            self.pbar.update()
+        self.pbar.close()
         return report
 
-    def get_graph_checks_report(self, root_folder: str, runner_filter: RunnerFilter, helmChart) -> Report:
+    def get_graph_checks_report(self, root_folder: str, runner_filter: RunnerFilter) -> Report:
         report = Report(self.check_type)
         checks_results = self.run_graph_checks_results(runner_filter)
         report = self.mutateKubernetesGraphResults(root_folder, runner_filter, report, checks_results)
@@ -113,22 +143,39 @@ class Runner(BaseRunner):
         # Moves report generation logic out of run() method in Runner class.
         # Allows function overriding of a much smaller function than run() for other "child" frameworks such as Kustomize, Helm
         # Where Kubernetes CHECKS are needed, but the specific file references are to another framework for the user output (or a mix of both).
-        for check, check_result in results.items():
+        if results:
+            for check, check_result in results.items():
+                resource_id = get_resource_id(entity_conf)
+                entity_context = self.context[k8_file][resource_id]
+
+                record = Record(
+                    check_id=check.id, bc_check_id=check.bc_id, check_name=check.name,
+                    check_result=check_result, code_block=entity_context.get("code_lines"), file_path=k8_file_path,
+                    file_line_range=[entity_context.get("start_line"), entity_context.get("end_line")],
+                    resource=resource_id, evaluations=variable_evaluations,
+                    check_class=check.__class__.__module__, file_abs_path=file_abs_path, severity=check.severity)
+                record.set_guideline(check.guideline)
+                report.add_record(record=record)
+        else:
             resource_id = get_resource_id(entity_conf)
-            entity_context = self.context[k8_file][resource_id]
+            # resources without checks, but not existing ones
+            report.extra_resources.add(
+                ExtraResource(
+                    file_abs_path=file_abs_path,
+                    file_path=k8_file_path,
+                    resource=resource_id,
+                )
+            )
 
-            record = Record(
-                check_id=check.id, bc_check_id=check.bc_id, check_name=check.name,
-                check_result=check_result, code_block=entity_context.get("code_lines"), file_path=k8_file_path,
-                file_line_range=[entity_context.get("start_line"), entity_context.get("end_line")],
-                resource=resource_id, evaluations=variable_evaluations,
-                check_class=check.__class__.__module__, file_abs_path=file_abs_path, severity=check.severity)
-            record.set_guideline(check.guideline)
-            report.add_record(record=record)
-        
         return report
 
-    def mutateKubernetesGraphResults(self, root_folder: str, runner_filter: RunnerFilter, report: Report, checks_results) -> Report:
+    def mutateKubernetesGraphResults(
+        self,
+        root_folder: str | None,
+        runner_filter: RunnerFilter,
+        report: Report,
+        checks_results: dict[BaseGraphCheck, list[dict[str, Any]]],
+    ) -> Report:
         # Moves report generation logic out of run() method in Runner class.
         # Allows function overriding of a much smaller function than run() for other "child" frameworks such as Kustomize, Helm
         # Where Kubernetes CHECKS are needed, but the specific file references are to another framework for the user output (or a mix of both).
@@ -158,7 +205,7 @@ class Runner(BaseRunner):
         return report
 
 
-def _get_entity_abs_path(root_folder, entity_file_path):
+def _get_entity_abs_path(root_folder: str | None, entity_file_path: str) -> str:
     if entity_file_path[0] == '/' and (root_folder and not entity_file_path.startswith(root_folder)):
         path_to_convert = (root_folder + entity_file_path) if root_folder else entity_file_path
     else:
@@ -172,18 +219,3 @@ def _get_from_dict(data_dict, map_list):
 
 def _set_in_dict(data_dict, map_list, value):
     _get_from_dict(data_dict, map_list[:-1])[map_list[-1]] = value
-
-
-def find_lines(node, kv):
-    if isinstance(node, str):
-        return node
-    if isinstance(node, list):
-        for i in node:
-            for x in find_lines(i, kv):
-                yield x
-    elif isinstance(node, dict):
-        if kv in node:
-            yield node[kv]
-        for j in node.values():
-            for x in find_lines(j, kv):
-                yield x
