@@ -28,7 +28,7 @@ class CPULimits(BaseResourceCheck):
                 resources = container.get("resources")[0]
                 if resources.get('limits'):
                     limits = resources.get('limits')[0]
-                    if limits.get('cpu'):
+                    if isinstance(limits, dict) and limits.get('cpu'):
                         return CheckResult.PASSED
                     self.evaluated_keys = [f'spec/[0]/container/[{idx}]/resources/[0]/limits']
                     return CheckResult.FAILED
