@@ -206,7 +206,8 @@ class TerraformLocalGraph(LocalGraph):
                                 self._create_edge(origin_node_index, dest_node_index, attribute_key)
                             break
 
-            if vertex.block_type == BlockType.MODULE and vertex.attributes.get('source'):
+            if vertex.block_type == BlockType.MODULE and vertex.attributes.get('source') \
+                    and isinstance(vertex.attributes.get('source')[0], str):
                 target_path = vertex.path
                 if vertex.module_dependency != "":
                     target_path = unify_dependency_path([vertex.module_dependency, vertex.path])
@@ -300,6 +301,9 @@ class TerraformLocalGraph(LocalGraph):
                 dest_module_path = next(
                     (path for path in self.relative_paths_cache.get(dest_module_source)), dest_module_path
                 )
+            except (OSError, ValueError):
+                logging.debug(f"Error to get dest_module_path {dest_module_source}", exc_info=True)
+                return ""
             except NotImplementedError as e:
                 if 'Non-relative patterns are unsupported' in str(e):
                     return ""
