@@ -10,8 +10,12 @@ from checkov.terraform.module_loading.loader import ModuleLoader
 class LocalPathLoader(ModuleLoader):
     def __init__(self) -> None:
         super().__init__()
+        self.discover()
         self.is_external = False
 
+    def discover(self):
+        pass
+
     def _is_matching_loader(self) -> bool:
         if (
             self.module_source.startswith("./")
