@@ -70,9 +70,11 @@ def should_download(path: str) -> bool:
     return not (path.startswith('./') or path.startswith('../') or path.startswith('/'))
 
 
-def load_tf_modules(path: str, should_download_module: Callable[[str], bool] = should_download, run_parallel=False):
+def load_tf_modules(path: str, should_download_module: Callable[[str], bool] = should_download, run_parallel=False,
+                    modules_to_load: List[ModuleDownload] = None):
     module_loader_registry.root_dir = path
-    modules_to_load = find_modules(path)
+    if not modules_to_load:
+        modules_to_load = find_modules(path)
 
     def _download_module(m):
         if should_download_module(m.module_link):
