@@ -11,7 +11,7 @@ if TYPE_CHECKING:
 
 
 class Runner(ObjectRunner):
-    check_type = CheckType.YAML
+    check_type = CheckType.YAML  # noqa: CCE003  # a static attribute
 
     def __init__(self) -> None:
         super().__init__()
@@ -23,10 +23,9 @@ class Runner(ObjectRunner):
         return registry
 
     def _parse_file(
-        self, f: str
+        self, f: str, file_content: str | None = None
     ) -> tuple[dict[str, Any] | list[dict[str, Any]], list[tuple[int, str]]] | None:
-        content: tuple[dict[str, Any] | list[dict[str, Any]], list[tuple[int, str]]] | None = parse(f)
-        return content
+        return parse(f, file_content)
 
     def get_start_end_lines(
         self, end: int, result_config: dict[str, Any] | list[dict[str, Any]], start: int
